__version__ = '0.0.4'
__author__ = u'Teakowa'
__author_email__ = 'git@teakowa.com'
__copyright__ = '2019 Teakowa'
__url__ = 'https://github.com/Teakowa/probable-happiness'


def get_version():
    return __version__
